@@ -20,6 +20,9 @@ function(doi,
   curl = getCurlHandle() ) {
     
   url2 <- paste(url, "/", doi, '.json?api_key=', key, sep='')
+  message(url2)
   tt <- getURLContent(url2)
-  fromJSON(I(tt))$article$citations_count
+  out <- fromJSON(I(tt))
+  out
+#   out$article$citations_count
 }
\ No newline at end of file
